package il.ac.tau.cs.sw1.sortedset;

/**
 * An iterator over a collection of elements.
 */
public interface Iterator<T> {
	/**
	 * Advances the iterator to the next element. This operation is valid only
	 * if the iterator is not at the end of the collection.
	 * 
	 * @throws NoSuchElementException
	 *             - iteration has no more elements (at the end)
	 */
	void advance();

	/**
	 * Returns <code>true</code> if there are no more elements to be traversed
	 * 
	 * @return <code>true</code> if there are no more elements to be traversed.
	 */
	boolean atEnd();

	/**
	 * Returns the current element. This operation is valid only if the iterator
	 * is not at the end of the collection.
	 * 
	 * @return the current element
	 * @throws NoSuchElementException
	 *             - - No current element (at the end)
	 */
	T get();
}
