package il.ac.tau.cs.sw1.sortedset;

/**
 * A Set that provides a total ordering on its elements. The elements are
 * ordered using their natural ordering. All elements must implement the
 * Comparable interface. The set's iterator will traverse the set in an
 * ascending element order.
 * All implementations of this interface prohibit the use of null elements.
 */
public interface SortedSet<T extends Comparable<T>> {

	/**
	 * Return <code>true</code> if this set contains the specified element.
	 * 
	 * @return <code>true</code> if this set contains the specified element
	 */
	boolean contains(T element);

	/**
	 * Return the maximal (highest) element in this set. Requires that the set
	 * be non-empty.
	 * 
	 * @return the maximal (highest) element in this set
	 * @throws NoSuchElementException
	 *             - if this set is empty
	 */
	T getMaximum();

	/**
	 * Return the minimal (lowest) element in this set. Requires that the set be
	 * non-empty.
	 * 
	 * @return the minimal (lowest) element in this set
	 * @throws NoSuchElementException
	 *             - if this set is empty
	 */
	T getMinimum();

	/**
	 * Return <code>true</code> if this set contains no elements.
	 * 
	 * @return <code>true</code> if this set contains no elements
	 */
	boolean isEmpty();

	/**
	 * Return an iterator over the elements of this set. The elements are
	 * returned in ascending order.
	 * 
	 * @return an iterator over the elements in this set
	 */
	Iterator<T> iterator();

	/**
	 * Return the number of elements in this set (its cardinality).
	 * 
	 * @return the number of elements in this set (its cardinality)
	 */
	int size();
	
}
